from __future__ import absolute_import
import falcon
import argparse
import time
import sys
import json

from netq_backend.lib.parser import (
    get_request_data,
    get_time,
)

'''
from netq_backend.modules.test_events import (
    get_event_counts,
    get_event_messages
)
'''

from netq_events.lib.event_database import EventDatabase

class EventCounts(object):

    def parse_request(self, req_data):
        (self.start_time, self.end_time, self.interval) = get_time(req_data)

        if not self.start_time or not self.end_time:
            self.end_time = int(time.time())
            self.start_time = self.end_time - 3600

        if not self.interval:
            self.interval = (self.end_time - self.start_time)/60

        self.filters = req_data.get('filters', {})

    def on_post(self, req, resp):
        '''
        Expect request format:
            {
               'startTime': <utc>,
               'endTime': <utc>,
               'timeInterval': <in secs>
               'filters': {
                   'severity' : [],
                   'eventType' : [],
                }
            }

            response format:
                {
                   'request': { ... echo request }
                   'data':  {
                      'startTimes': [

                      ],
                    'eventCounts': {
                       'eventType': [ { 'total' : <>, 'CRITICAL': <x> , ...}, {...} ],
                      },
                      ...
                    ]
                }
        '''
        try:
            req_data = get_request_data(req)
        except Exception as e:
            resp.status = falcon.HTTP_400
            resp.content_type = 'application/json'
            resp.data = json.dumps('Invalid POST data')
            return

        self.parse_request(req_data)

        # Query for events 
        '''
        data = get_event_counts(self.start_time,
                                self.end_time,
                                self.interval,
                                self.filters)

        '''
        db = EventDatabase()
        data = db.event_count(self.start_time,
                              self.end_time,
                              self.interval,
                              self.filters)
        resp_data = {
            'request': req_data,
            'data': data
        }
        resp.data = json.dumps(resp_data)
        resp.status = falcon.HTTP_200
        resp.content_type = 'application/json'
        return

class EventMessages(object):
    def __init__(self):
        pass

    def parse_request(self, req_data):
        (self.start_time, self.end_time, self.interval) = get_time(req_data)
        if not self.start_time or not self.end_time:
            self.end_time = int(time.time())
            self.start_time = self.end_time - 3600
        self.filters = req_data.get('filters', {})

    def on_post(self, req, resp):
        '''
        Expect request format:
            {
               'startTime': <utc>,
               'endTime': <utc>,
               'filters': {
                   'severity' : [],
                   'eventType' : [],
                   'sources': [],
                }
            }

            response format:
                {
                   'request': { ... echo request }
                   'events':  [
                      {
                         'timestamp': <utc>,
                         'eventType': <eventType>,
                         'severity': <level>,
                         'eventMessages': event_message,
                      },
                      ...
                    ]
                }
        '''
        try:
            req_data = get_request_data(req)
        except Exception as e:
            resp.status = falcon.HTTP_400
            resp.content_type = 'application/json'
            resp.data = json.dumps('Invalid POST data')
            return

        self.parse_request(req_data)

        # Query for events 
        '''
        event_messages = get_event_messages(self.start_time,
                                            self.end_time,
                                            self.filters)

        '''
        db = EventDatabase()
        event_messages = db.event_messages(self.start_time,
                                           self.end_time,
                                           self.filters)

        resp_data = {
            'request': req_data,
            'eventMessages': event_messages
        }
        resp.data = json.dumps(resp_data)
        resp.status = falcon.HTTP_200
        resp.content_type = 'application/json'
        return
