from __future__ import absolute_import
import falcon
import argparse
import time
import sys
import json

from subprocess import CalledProcessError, check_output, STDOUT
from netq_backend.lib.parser import (
    get_request_data,
)


class NetqQuery(object):

    def parse_request(self, req_data):
        self.query_string = req_data.get('query', None)
        if self.query_string:
            self.query_string = str(self.query_string)
        return

    def on_post(self, req, resp):
        '''
        Expect request format:
            {
               'query': <query string>
            }
        '''
        output = None
        error = None

        try:
            req_data = get_request_data(req)
        except Exception as e:
            resp.status = falcon.HTTP_400
            resp.content_type = 'application/json'
            resp.data = json.dumps('Invalid POST data')
            return

        self.parse_request(req_data)

        if not self.query_string:
            resp.status = falcon.HTTP_400
            resp.content_type = 'application/json'
            resp.data = json.dumps('Missing query')
            return

        if self.query_string.startswith('netq'):
            try:
                output = check_output(('{0}'.format(self.query_string)).split(), stderr=STDOUT)
            except CalledProcessError as e:
                error = 'Command failed with error:  {}'.format(e)
                output = None
            except Exception as e:
                error = 'Request failed due to {}'.format(e)
                output = None
        else:
            resp.status = falcon.HTTP_400
            resp.content_type = 'application/json'
            resp_data = {
                'request': req_data,
                'error': "Invalid Query. Only 'netq ...' commands are supported"
            }
            resp.data = json.dumps(resp_data)
            return


        if not output:
            resp_data = {
                'request': req_data,
                'error': error
            }
        else:
            if "json" in self.query_string:
                output = json.loads(output)

            resp_data = {
                'request': req_data,
                'netq': output
            }
        resp.data = json.dumps(resp_data)
        resp.status = falcon.HTTP_200
        resp.content_type = 'application/json'
        return
