import random
import time
import argparse

from netq_events.lib.event_database import (
    EventDatabase,
    EventObject,
    EventType,
    EventSeverity
)

_PROC_NAME = 'test_events'
#
# Place holder for testing GUI
#
test_event_messages = [
    {
      'timestamp': 1507782880,
      'eventType': 'Link',
      'source': 'hosts-11',
      'severity': 'CRITICAL',
      'message': 'Link down'
    },
    {
      'timestamp': 1507782895,
      'eventType': 'Link',
      'source': 'hosts-11',
      'severity': 'WARNING',
      'message': 'Link speed change'
    },
    {
      'timestamp': 1507782910,
      'eventType': 'Link',
      'source': 'torc-11',
      'severity': 'CRITICAL',
      'message': 'Link down'
    },
    {
      'timestamp': 1507782925,
      'eventType': 'Link',
      'source': 'torc-12',
      'severity': 'INFO',
      'message': 'Link up'
    },
    {
      'timestamp': 1507782940,
      'eventType': 'Bgp',
      'source': 'torc-11',
      'severity': 'CRITICAL',
      'message': 'Session Down'
    },
    {
      'timestamp': 1507782942,
      'eventType': 'Bgp',
      'source': 'torc-21',
      'severity': 'CRITICAL',
      'message': 'Session Down'
    },
    {
      'timestamp': 1507782943,
      'eventType': 'Bgp',
      'source': 'torc-12',
      'severity': 'INFO',
      'message': 'Session up'
    },
    {
      'timestamp': 1507782953,
      'eventType': 'Ospf',
      'source': 'exit-1',
      'severity': 'CRITICAL',
      'message': 'process crash'
    },
    {
      'timestamp': 1507782958,
      'eventType': 'Ospf',
      'source': 'noc-pr',
      'severity': 'WARNING',
      'message': 'Ospf DR changed'
    },
    {
      'timestamp': 1507782968,
      'eventType': 'Ospf',
      'source': 'torc-21',
      'severity': 'CRITICAL',
      'message': 'Ospf adjacency lost'
    },
    {
      'timestamp': 1507782980,
      'eventType': 'Ospf',
      'source': 'torc-12',
      'severity': 'INFO',
      'message': 'Ospf adjacency established'
    },
]

event_type_list = [ 'Bgp', 'Vlan', 'Link', 'Clag', 'Port', 'Lldp', 'Sensor', 'Ospf', 'Service' ]
event_severity_list = [ 'CRITICAL', 'WARNING', 'INFO' ]


def get_event_counts(start_time, end_time, interval, filters):

    event_type_filter = filters.get('eventType', None)
    severity_filter = filters.get('severity', None)

    data = {}
    start_time_list = [ ts for ts in range(start_time, end_time, interval) ]

    data['startTimes'] = start_time_list

    event_counts = {}
    for event_type in event_type_list:

        # If filter is defined, include only the event_types specified 
        # in the filter (it's an include filter)
        if event_type_filter and event_type not in event_type_filter:
            continue

        counter_list = []
        for ts in start_time_list:
            counters = {}
            total = 0
            for severity in event_severity_list:
                if severity_filter and severity not in severity_filter:
                    continue

                counters[severity] = random.randint(0, 100)
                total = total + counters[severity]
            counters['total'] = total
            counter_list.append(counters)
        event_counts[event_type] = counter_list

    data['eventCounts'] = event_counts
    return data

def get_event_messages(start_time, end_time, filters):
    eventType = filters.get('eventType', None)
    sources = filters.get('sources', None)
    severity = filters.get('severity', None)

    event_list = []
    for event in test_event_messages:
        source = event.get('source')
        level = event.get('severity')
        eventType = event.get('eventType')

        if eventType and eventType not in eventType:
            continue

        if sources and source not in sources:
            continue

        if severity and level not in severity:
            continue

        event_list.append(event)

    return event_list

if __name__ == '__main__':
    parser = argparse.ArgumentParser(prog=_PROC_NAME,
                                     description='Netq Event Generator tool')

    parser.add_argument('-c', '--count', dest='count', type=int, default=100,
                         help='Specify number of event entries to generate')

    args = parser.parse_args()
    count = args.count

    db = EventDatabase()
    for _ in range(0, count):
        time.sleep(0.01)
        e  = EventObject(timestamp=int(time.time()),
                        eventType=random.choice(EventType),
                        severity=random.choice(EventSeverity),
                        message='This is a generated message')
        db.save(e)
    db.commit()
