# Copyright 2017 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt
from __future__ import absolute_import
import time
from logging import DEBUG, INFO, WARNING, ERROR, CRITICAL
from netq_apps.lib.integrations import Integration
from netq_apps.lib.events import EventService
from netq_lib.common import utils
_PROC_NAME = 'netq-eventd'
SEVERITY = 'severity'
MESSAGE = 'message'
DIFF = 'diff'

from netq_events.lib.event_database import EventDatabase, EventObject


class InfluxDb(Integration):

    def verify_conf(self, conf):
        return True

    def populate_request(self, conf):
        try:
            self.conf['event_db'] = EventDatabase()
            self.conf['log_severity'] = {
                INFO: 'INFO', DEBUG: 'DEBUG', WARNING: 'WARNING',
                ERROR: 'ERROR', CRITICAL: 'CRITICAL'}
        except:
            self.log_integration(WARNING, 'Failed to initialize Event database')
        self.conf['event_db'] = None

    def post(self, msg):
        m_type = msg.get('type', 'unknown')
        db = EventDatabase()
        if not db:
            return 'Event DB not initialized'
        if msg.get(DIFF):
            event_object = EventObject(
                 timestamp=int(time.time()), eventType=m_type,
                 severity=self.conf['log_severity'][msg.get(SEVERITY, INFO)],
                 message=msg.get(MESSAGE))
            db.save(event_object)
            db.commit()


def main():
    conf_dict = utils.get_yaml_config(_PROC_NAME)
    conf_dict['event-integrations'] = [{'type': 'influxdb', 'name': 'influxdb'}]
    conf_dict['event-filters'] = [{'output': ['influxdb'], 'name': 'default',
                                   'rule': None}]
    integ_map = {'influxdb': InfluxDb}
    event_inst = EventService(conf_dict, _PROC_NAME, integ_map,
                              'event-filters', 'event-integrations')
    return event_inst.run()
